pub struct CompoundShape<const D: usize> { /* private fields */ }Expand description
A convex rigid body composed of multiple child shapes.
The overall support function is the argmax of all children’s support
points transformed into the compound’s local frame. This makes compound
shapes first-class Shape<D> objects compatible with GJK.
Implementations
Sourceimpl<const D: usize> CompoundShape<D>
impl<const D: usize> CompoundShape<D>